# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/novasoft/flight/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/novasoft/flight/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Novasoft\\Flight\\": "packages/novasoft/flight/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Novasoft\Flight\Providers\FlightServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Flight'  => Novasoft\Flight\Facades\Flight::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Novasoft\\FlightTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Novasoft\Flight\Providers\FlightServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Novasoft\Flight\Providers\FlightServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Novasoft\Flight\Providers\FlightServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/flight/{modulename}

**User**

    http://path-to-route-folder/user/flight/{modulename}

**Public**

    http://path-to-route-folder/flights


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/flight/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/flight/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/flight/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/flight/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/flight/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/flight/{modulename}/{slug}
    METHOD: GET